@@ -20,28 +20,46 @@
 ## Seriation generic and default method.
 seriate <- function(x, ...)
   UseMethod("seriate")
-seriate.default <- function(x, ...) 
+seriate.default <- function(x, ...)
   stop(gettextf("seriate not implemented for class '%s'.",
     class(x)))
 
 ## Seriation methods db.
-get_seriation_method <- function(kind, name)
-  registry_seriate$get_entry(kind=kind, name=name)
+get_seriation_method <- function(kind, name) {
+  method <- registry_seriate$get_entry(kind=kind, name=name)
+
+  if(is.null(method))
+    stop("Unknown seriation method. Check list_seriation_methods(\"",
+      kind, "\")")
+
+  method
+}
 
 set_seriation_method <-
   function(kind, name, definition, description = NULL, ...){
-    
+
     ## check formals
     if(!identical(names(formals(definition)),
       c("x", "control")))
       stop("Seriation methods must have formals 'x' and 'control'.")
-    
-    registry_seriate$set_entry(name=name, kind=kind, fun=definition,
-      description=description)
+
+    ## check if entry already exists
+    r <- registry_seriate$get_entry(kind=kind, name=name)
+    if(!is.null(r) && r$name==name) {
+      warning("Entry with name \"", name, "\" for kind \"", kind,
+        "\" already exists! Modifying entry.")
+      registry_seriate$modify_entry(kind=kind, name=name, fun=definition,
+        description=description)
+    } else {
+      registry_seriate$set_entry(name=name, kind=kind, fun=definition,
+        description=description)
+    }
   }
 
 list_seriation_methods <- function(kind)
-  as.vector(sapply(registry_seriate$get_entries(kind=kind), "[[", "name"))
+  sort(as.vector(sapply(registry_seriate$get_entries(kind=kind), "[[", "name")))
 
-show_seriation_methods <- function(kind)
-  registry_seriate$get_entries(kind=kind)
\ No newline at end of file
+show_seriation_methods <- function(kind){
+  m <- registry_seriate$get_entries(kind=kind)
+  m[sort(names(m))]
+}
